@@ -14,9 +14,10 @@ has storage => (is => 'rw', isa => 'HashRef',
                         'db_id', 'name',
                       ],
                       rows => [
-                        [ 100, 'core' ],
+                        [ 100, 'OBO_REL' ],
                         [ 101, 'internal' ],
                       ],
+                      unique_columns => ['name'],
                     },
                     dbxref =>{
                       id_counter => 203,
@@ -28,6 +29,7 @@ has storage => (is => 'rw', isa => 'HashRef',
                         [ 201, 'exact', 101 ],
                         [ 202, 'narrow', 101 ],
                       ],
+                      unique_columns => ['accession', 'db_id'],
                     },
                     cv => {
                       id_counter => 302,
@@ -35,9 +37,10 @@ has storage => (is => 'rw', isa => 'HashRef',
                         'cv_id', 'name',
                       ],
                       rows => [
-                        [ 300, 'core' ],
+                        [ 300, 'relationship' ],
                         [ 301, 'synonym_type' ],
-                      ]
+                      ],
+                      unique_columns => ['name'],
                     },
                     cvterm => {
                       id_counter => 401,
@@ -49,7 +52,8 @@ has storage => (is => 'rw', isa => 'HashRef',
                         [ 400, 'is_a', 300, 200, 1, 0],
                         [ 401, 'exact', 301, 201, 0, 0],
                         [ 402, 'narrow', 301, 202, 0, 0],
-                      ]
+                      ],
+                      unique_columns => ['name', 'cv_id'],
                     },
                     cvtermsynonym => {
                       id_counter => 501,
